==> zio-aws-workspaces_3-5.17.171.1-sources.jar: zio/aws/workspaces/model/Workspace.scala <==
package zio.aws.workspaces.model
import zio.aws.workspaces.model.primitives.{
  SubnetId,
  BooleanObject,
  WorkspaceId,
  ComputerName,
  IpAddress,
  Description,
  WorkspaceErrorCode,
  BundleId,
  UserName,
  DirectoryId,
  VolumeEncryptionKey
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class Workspace(
    workspaceId: Optional[WorkspaceId] = Optional.Absent,
    directoryId: Optional[DirectoryId] = Optional.Absent,
    userName: Optional[UserName] = Optional.Absent,
    ipAddress: Optional[IpAddress] = Optional.Absent,
    state: Optional[zio.aws.workspaces.model.WorkspaceState] = Optional.Absent,
    bundleId: Optional[BundleId] = Optional.Absent,
    subnetId: Optional[SubnetId] = Optional.Absent,
    errorMessage: Optional[Description] = Optional.Absent,
    errorCode: Optional[WorkspaceErrorCode] = Optional.Absent,
    computerName: Optional[ComputerName] = Optional.Absent,
    volumeEncryptionKey: Optional[VolumeEncryptionKey] = Optional.Absent,
    userVolumeEncryptionEnabled: Optional[BooleanObject] = Optional.Absent,
    rootVolumeEncryptionEnabled: Optional[BooleanObject] = Optional.Absent,
    workspaceProperties: Optional[
      zio.aws.workspaces.model.WorkspaceProperties
    ] = Optional.Absent,
    modificationStates: Optional[
      Iterable[zio.aws.workspaces.model.ModificationState]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.workspaces.model.Workspace = {
    import Workspace.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.workspaces.model.Workspace
      .builder()
      .optionallyWith(
        workspaceId.map(value => WorkspaceId.unwrap(value): java.lang.String)
      )(_.workspaceId)
      .optionallyWith(
        directoryId.map(value => DirectoryId.unwrap(value): java.lang.String)
      )(_.directoryId)
      .optionallyWith(
        userName.map(value => UserName.unwrap(value): java.lang.String)
      )(_.userName)
      .optionallyWith(
        ipAddress.map(value => IpAddress.unwrap(value): java.lang.String)
      )(_.ipAddress)
      .optionallyWith(state.map(value => value.unwrap))(_.state)
      .optionallyWith(
        bundleId.map(value => BundleId.unwrap(value): java.lang.String)
      )(_.bundleId)
      .optionallyWith(
        subnetId.map(value => SubnetId.unwrap(value): java.lang.String)
      )(_.subnetId)
      .optionallyWith(
        errorMessage.map(value => Description.unwrap(value): java.lang.String)
      )(_.errorMessage)
      .optionallyWith(
        errorCode.map(value =>
          WorkspaceErrorCode.unwrap(value): java.lang.String
        )
      )(_.errorCode)
      .optionallyWith(
        computerName.map(value => ComputerName.unwrap(value): java.lang.String)
      )(_.computerName)
      .optionallyWith(
        volumeEncryptionKey.map(value =>
          VolumeEncryptionKey.unwrap(value): java.lang.String
        )
      )(_.volumeEncryptionKey)
      .optionallyWith(
        userVolumeEncryptionEnabled.map(value => value: java.lang.Boolean)
      )(_.userVolumeEncryptionEnabled)
      .optionallyWith(
        rootVolumeEncryptionEnabled.map(value => value: java.lang.Boolean)
      )(_.rootVolumeEncryptionEnabled)
      .optionallyWith(workspaceProperties.map(value => value.buildAwsValue()))(
        _.workspaceProperties
      )
      .optionallyWith(
        modificationStates.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.modificationStates)
      .build()
  }
  def asReadOnly: zio.aws.workspaces.model.Workspace.ReadOnly =
    zio.aws.workspaces.model.Workspace.wrap(buildAwsValue())
}
object Workspace {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.workspaces.model.Workspace
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.workspaces.model.Workspace =
      zio.aws.workspaces.model.Workspace(
        workspaceId.map(value => value),
        directoryId.map(value => value),
        userName.map(value => value),
        ipAddress.map(value => value),
        state.map(value => value),
        bundleId.map(value => value),
        subnetId.map(value => value),
        errorMessage.map(value => value),
        errorCode.map(value => value),
        computerName.map(value => value),
        volumeEncryptionKey.map(value => value),
        userVolumeEncryptionEnabled.map(value => value),
        rootVolumeEncryptionEnabled.map(value => value),
        workspaceProperties.map(value => value.asEditable),
        modificationStates.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def workspaceId: Optional[WorkspaceId]
    def directoryId: Optional[DirectoryId]
    def userName: Optional[UserName]
    def ipAddress: Optional[IpAddress]
    def state: Optional[zio.aws.workspaces.model.WorkspaceState]
    def bundleId: Optional[BundleId]
    def subnetId: Optional[SubnetId]
    def errorMessage: Optional[Description]
    def errorCode: Optional[WorkspaceErrorCode]
    def computerName: Optional[ComputerName]
    def volumeEncryptionKey: Optional[VolumeEncryptionKey]
    def userVolumeEncryptionEnabled: Optional[BooleanObject]
    def rootVolumeEncryptionEnabled: Optional[BooleanObject]
    def workspaceProperties
        : Optional[zio.aws.workspaces.model.WorkspaceProperties.ReadOnly]
    def modificationStates
        : Optional[List[zio.aws.workspaces.model.ModificationState.ReadOnly]]
    def getWorkspaceId: ZIO[Any, AwsError, WorkspaceId] =
      AwsError.unwrapOptionField("workspaceId", workspaceId)
    def getDirectoryId: ZIO[Any, AwsError, DirectoryId] =
      AwsError.unwrapOptionField("directoryId", directoryId)
    def getUserName: ZIO[Any, AwsError, UserName] =
      AwsError.unwrapOptionField("userName", userName)
    def getIpAddress: ZIO[Any, AwsError, IpAddress] =
      AwsError.unwrapOptionField("ipAddress", ipAddress)
    def getState: ZIO[Any, AwsError, zio.aws.workspaces.model.WorkspaceState] =
      AwsError.unwrapOptionField("state", state)
    def getBundleId: ZIO[Any, AwsError, BundleId] =
      AwsError.unwrapOptionField("bundleId", bundleId)
    def getSubnetId: ZIO[Any, AwsError, SubnetId] =
      AwsError.unwrapOptionField("subnetId", subnetId)
    def getErrorMessage: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("errorMessage", errorMessage)
    def getErrorCode: ZIO[Any, AwsError, WorkspaceErrorCode] =
      AwsError.unwrapOptionField("errorCode", errorCode)
    def getComputerName: ZIO[Any, AwsError, ComputerName] =
      AwsError.unwrapOptionField("computerName", computerName)
    def getVolumeEncryptionKey: ZIO[Any, AwsError, VolumeEncryptionKey] =
      AwsError.unwrapOptionField("volumeEncryptionKey", volumeEncryptionKey)
    def getUserVolumeEncryptionEnabled: ZIO[Any, AwsError, BooleanObject] =
      AwsError.unwrapOptionField(
        "userVolumeEncryptionEnabled",
        userVolumeEncryptionEnabled
      )
    def getRootVolumeEncryptionEnabled: ZIO[Any, AwsError, BooleanObject] =
      AwsError.unwrapOptionField(
        "rootVolumeEncryptionEnabled",
        rootVolumeEncryptionEnabled
      )
    def getWorkspaceProperties: ZIO[
      Any,
      AwsError,
      zio.aws.workspaces.model.WorkspaceProperties.ReadOnly
    ] = AwsError.unwrapOptionField("workspaceProperties", workspaceProperties)
    def getModificationStates: ZIO[Any, AwsError, List[
      zio.aws.workspaces.model.ModificationState.ReadOnly
    ]] = AwsError.unwrapOptionField("modificationStates", modificationStates)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.workspaces.model.Workspace
  ) extends zio.aws.workspaces.model.Workspace.ReadOnly {
    override val workspaceId: Optional[WorkspaceId] = zio.aws.core.internal
      .optionalFromNullable(impl.workspaceId())
      .map(value => zio.aws.workspaces.model.primitives.WorkspaceId(value))
    override val directoryId: Optional[DirectoryId] = zio.aws.core.internal
      .optionalFromNullable(impl.directoryId())
      .map(value => zio.aws.workspaces.model.primitives.DirectoryId(value))
    override val userName: Optional[UserName] = zio.aws.core.internal
      .optionalFromNullable(impl.userName())
      .map(value => zio.aws.workspaces.model.primitives.UserName(value))
    override val ipAddress: Optional[IpAddress] = zio.aws.core.internal
      .optionalFromNullable(impl.ipAddress())
      .map(value => zio.aws.workspaces.model.primitives.IpAddress(value))
    override val state: Optional[zio.aws.workspaces.model.WorkspaceState] =
      zio.aws.core.internal
        .optionalFromNullable(impl.state())
        .map(value => zio.aws.workspaces.model.WorkspaceState.wrap(value))
    override val bundleId: Optional[BundleId] = zio.aws.core.internal
      .optionalFromNullable(impl.bundleId())
      .map(value => zio.aws.workspaces.model.primitives.BundleId(value))
    override val subnetId: Optional[SubnetId] = zio.aws.core.internal
      .optionalFromNullable(impl.subnetId())
      .map(value => zio.aws.workspaces.model.primitives.SubnetId(value))
    override val errorMessage: Optional[Description] = zio.aws.core.internal
      .optionalFromNullable(impl.errorMessage())
      .map(value => zio.aws.workspaces.model.primitives.Description(value))
    override val errorCode: Optional[WorkspaceErrorCode] = zio.aws.core.internal
      .optionalFromNullable(impl.errorCode())
      .map(value =>
        zio.aws.workspaces.model.primitives.WorkspaceErrorCode(value)
      )
    override val computerName: Optional[ComputerName] = zio.aws.core.internal
      .optionalFromNullable(impl.computerName())
      .map(value => zio.aws.workspaces.model.primitives.ComputerName(value))
    override val volumeEncryptionKey: Optional[VolumeEncryptionKey] =
      zio.aws.core.internal
        .optionalFromNullable(impl.volumeEncryptionKey())
        .map(value =>
          zio.aws.workspaces.model.primitives.VolumeEncryptionKey(value)
        )
    override val userVolumeEncryptionEnabled: Optional[BooleanObject] =
      zio.aws.core.internal
        .optionalFromNullable(impl.userVolumeEncryptionEnabled())
        .map(value => value: BooleanObject)
    override val rootVolumeEncryptionEnabled: Optional[BooleanObject] =
      zio.aws.core.internal
        .optionalFromNullable(impl.rootVolumeEncryptionEnabled())
        .map(value => value: BooleanObject)
    override val workspaceProperties
        : Optional[zio.aws.workspaces.model.WorkspaceProperties.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.workspaceProperties())
        .map(value => zio.aws.workspaces.model.WorkspaceProperties.wrap(value))
    override val modificationStates
        : Optional[List[zio.aws.workspaces.model.ModificationState.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.modificationStates())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.workspaces.model.ModificationState.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.workspaces.model.Workspace
  ): zio.aws.workspaces.model.Workspace.ReadOnly = new Wrapper(impl)
}

==> zio-aws-workspaces_3-7.21.15.7-sources.jar: zio/aws/workspaces/model/Workspace.scala <==
package zio.aws.workspaces.model
import zio.aws.workspaces.model.primitives.{
  SubnetId,
  BooleanObject,
  WorkspaceId,
  ComputerName,
  IpAddress,
  Description,
  WorkspaceErrorCode,
  BundleId,
  UserName,
  DirectoryId,
  VolumeEncryptionKey
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class Workspace(
    workspaceId: Optional[WorkspaceId] = Optional.Absent,
    directoryId: Optional[DirectoryId] = Optional.Absent,
    userName: Optional[UserName] = Optional.Absent,
    ipAddress: Optional[IpAddress] = Optional.Absent,
    state: Optional[zio.aws.workspaces.model.WorkspaceState] = Optional.Absent,
    bundleId: Optional[BundleId] = Optional.Absent,
    subnetId: Optional[SubnetId] = Optional.Absent,
    errorMessage: Optional[Description] = Optional.Absent,
    errorCode: Optional[WorkspaceErrorCode] = Optional.Absent,
    computerName: Optional[ComputerName] = Optional.Absent,
    volumeEncryptionKey: Optional[VolumeEncryptionKey] = Optional.Absent,
    userVolumeEncryptionEnabled: Optional[BooleanObject] = Optional.Absent,
    rootVolumeEncryptionEnabled: Optional[BooleanObject] = Optional.Absent,
    workspaceProperties: Optional[
      zio.aws.workspaces.model.WorkspaceProperties
    ] = Optional.Absent,
    modificationStates: Optional[
      Iterable[zio.aws.workspaces.model.ModificationState]
    ] = Optional.Absent,
    relatedWorkspaces: Optional[
      Iterable[zio.aws.workspaces.model.RelatedWorkspaceProperties]
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.workspaces.model.Workspace = {
    import Workspace.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.workspaces.model.Workspace
      .builder()
      .optionallyWith(
        workspaceId.map(value => WorkspaceId.unwrap(value): java.lang.String)
      )(_.workspaceId)
      .optionallyWith(
        directoryId.map(value => DirectoryId.unwrap(value): java.lang.String)
      )(_.directoryId)
      .optionallyWith(
        userName.map(value => UserName.unwrap(value): java.lang.String)
      )(_.userName)
      .optionallyWith(
        ipAddress.map(value => IpAddress.unwrap(value): java.lang.String)
      )(_.ipAddress)
      .optionallyWith(state.map(value => value.unwrap))(_.state)
      .optionallyWith(
        bundleId.map(value => BundleId.unwrap(value): java.lang.String)
      )(_.bundleId)
      .optionallyWith(
        subnetId.map(value => SubnetId.unwrap(value): java.lang.String)
      )(_.subnetId)
      .optionallyWith(
        errorMessage.map(value => Description.unwrap(value): java.lang.String)
      )(_.errorMessage)
      .optionallyWith(
        errorCode.map(value =>
          WorkspaceErrorCode.unwrap(value): java.lang.String
        )
      )(_.errorCode)
      .optionallyWith(
        computerName.map(value => ComputerName.unwrap(value): java.lang.String)
      )(_.computerName)
      .optionallyWith(
        volumeEncryptionKey.map(value =>
          VolumeEncryptionKey.unwrap(value): java.lang.String
        )
      )(_.volumeEncryptionKey)
      .optionallyWith(
        userVolumeEncryptionEnabled.map(value => value: java.lang.Boolean)
      )(_.userVolumeEncryptionEnabled)
      .optionallyWith(
        rootVolumeEncryptionEnabled.map(value => value: java.lang.Boolean)
      )(_.rootVolumeEncryptionEnabled)
      .optionallyWith(workspaceProperties.map(value => value.buildAwsValue()))(
        _.workspaceProperties
      )
      .optionallyWith(
        modificationStates.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.modificationStates)
      .optionallyWith(
        relatedWorkspaces.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.relatedWorkspaces)
      .build()
  }
  def asReadOnly: zio.aws.workspaces.model.Workspace.ReadOnly =
    zio.aws.workspaces.model.Workspace.wrap(buildAwsValue())
}
object Workspace {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.workspaces.model.Workspace
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.workspaces.model.Workspace =
      zio.aws.workspaces.model.Workspace(
        workspaceId.map(value => value),
        directoryId.map(value => value),
        userName.map(value => value),
        ipAddress.map(value => value),
        state.map(value => value),
        bundleId.map(value => value),
        subnetId.map(value => value),
        errorMessage.map(value => value),
        errorCode.map(value => value),
        computerName.map(value => value),
        volumeEncryptionKey.map(value => value),
        userVolumeEncryptionEnabled.map(value => value),
        rootVolumeEncryptionEnabled.map(value => value),
        workspaceProperties.map(value => value.asEditable),
        modificationStates.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        relatedWorkspaces.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def workspaceId: Optional[WorkspaceId]
    def directoryId: Optional[DirectoryId]
    def userName: Optional[UserName]
    def ipAddress: Optional[IpAddress]
    def state: Optional[zio.aws.workspaces.model.WorkspaceState]
    def bundleId: Optional[BundleId]
    def subnetId: Optional[SubnetId]
    def errorMessage: Optional[Description]
    def errorCode: Optional[WorkspaceErrorCode]
    def computerName: Optional[ComputerName]
    def volumeEncryptionKey: Optional[VolumeEncryptionKey]
    def userVolumeEncryptionEnabled: Optional[BooleanObject]
    def rootVolumeEncryptionEnabled: Optional[BooleanObject]
    def workspaceProperties
        : Optional[zio.aws.workspaces.model.WorkspaceProperties.ReadOnly]
    def modificationStates
        : Optional[List[zio.aws.workspaces.model.ModificationState.ReadOnly]]
    def relatedWorkspaces: Optional[
      List[zio.aws.workspaces.model.RelatedWorkspaceProperties.ReadOnly]
    ]
    def getWorkspaceId: ZIO[Any, AwsError, WorkspaceId] =
      AwsError.unwrapOptionField("workspaceId", workspaceId)
    def getDirectoryId: ZIO[Any, AwsError, DirectoryId] =
      AwsError.unwrapOptionField("directoryId", directoryId)
    def getUserName: ZIO[Any, AwsError, UserName] =
      AwsError.unwrapOptionField("userName", userName)
    def getIpAddress: ZIO[Any, AwsError, IpAddress] =
      AwsError.unwrapOptionField("ipAddress", ipAddress)
    def getState: ZIO[Any, AwsError, zio.aws.workspaces.model.WorkspaceState] =
      AwsError.unwrapOptionField("state", state)
    def getBundleId: ZIO[Any, AwsError, BundleId] =
      AwsError.unwrapOptionField("bundleId", bundleId)
    def getSubnetId: ZIO[Any, AwsError, SubnetId] =
      AwsError.unwrapOptionField("subnetId", subnetId)
    def getErrorMessage: ZIO[Any, AwsError, Description] =
      AwsError.unwrapOptionField("errorMessage", errorMessage)
    def getErrorCode: ZIO[Any, AwsError, WorkspaceErrorCode] =
      AwsError.unwrapOptionField("errorCode", errorCode)
    def getComputerName: ZIO[Any, AwsError, ComputerName] =
      AwsError.unwrapOptionField("computerName", computerName)
    def getVolumeEncryptionKey: ZIO[Any, AwsError, VolumeEncryptionKey] =
      AwsError.unwrapOptionField("volumeEncryptionKey", volumeEncryptionKey)
    def getUserVolumeEncryptionEnabled: ZIO[Any, AwsError, BooleanObject] =
      AwsError.unwrapOptionField(
        "userVolumeEncryptionEnabled",
        userVolumeEncryptionEnabled
      )
    def getRootVolumeEncryptionEnabled: ZIO[Any, AwsError, BooleanObject] =
      AwsError.unwrapOptionField(
        "rootVolumeEncryptionEnabled",
        rootVolumeEncryptionEnabled
      )
    def getWorkspaceProperties: ZIO[
      Any,
      AwsError,
      zio.aws.workspaces.model.WorkspaceProperties.ReadOnly
    ] = AwsError.unwrapOptionField("workspaceProperties", workspaceProperties)
    def getModificationStates: ZIO[Any, AwsError, List[
      zio.aws.workspaces.model.ModificationState.ReadOnly
    ]] = AwsError.unwrapOptionField("modificationStates", modificationStates)
    def getRelatedWorkspaces: ZIO[Any, AwsError, List[
      zio.aws.workspaces.model.RelatedWorkspaceProperties.ReadOnly
    ]] = AwsError.unwrapOptionField("relatedWorkspaces", relatedWorkspaces)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.workspaces.model.Workspace
  ) extends zio.aws.workspaces.model.Workspace.ReadOnly {
    override val workspaceId: Optional[WorkspaceId] = zio.aws.core.internal
      .optionalFromNullable(impl.workspaceId())
      .map(value => zio.aws.workspaces.model.primitives.WorkspaceId(value))
    override val directoryId: Optional[DirectoryId] = zio.aws.core.internal
      .optionalFromNullable(impl.directoryId())
      .map(value => zio.aws.workspaces.model.primitives.DirectoryId(value))
    override val userName: Optional[UserName] = zio.aws.core.internal
      .optionalFromNullable(impl.userName())
      .map(value => zio.aws.workspaces.model.primitives.UserName(value))
    override val ipAddress: Optional[IpAddress] = zio.aws.core.internal
      .optionalFromNullable(impl.ipAddress())
      .map(value => zio.aws.workspaces.model.primitives.IpAddress(value))
    override val state: Optional[zio.aws.workspaces.model.WorkspaceState] =
      zio.aws.core.internal
        .optionalFromNullable(impl.state())
        .map(value => zio.aws.workspaces.model.WorkspaceState.wrap(value))
    override val bundleId: Optional[BundleId] = zio.aws.core.internal
      .optionalFromNullable(impl.bundleId())
      .map(value => zio.aws.workspaces.model.primitives.BundleId(value))
    override val subnetId: Optional[SubnetId] = zio.aws.core.internal
      .optionalFromNullable(impl.subnetId())
      .map(value => zio.aws.workspaces.model.primitives.SubnetId(value))
    override val errorMessage: Optional[Description] = zio.aws.core.internal
      .optionalFromNullable(impl.errorMessage())
      .map(value => zio.aws.workspaces.model.primitives.Description(value))
    override val errorCode: Optional[WorkspaceErrorCode] = zio.aws.core.internal
      .optionalFromNullable(impl.errorCode())
      .map(value =>
        zio.aws.workspaces.model.primitives.WorkspaceErrorCode(value)
      )
    override val computerName: Optional[ComputerName] = zio.aws.core.internal
      .optionalFromNullable(impl.computerName())
      .map(value => zio.aws.workspaces.model.primitives.ComputerName(value))
    override val volumeEncryptionKey: Optional[VolumeEncryptionKey] =
      zio.aws.core.internal
        .optionalFromNullable(impl.volumeEncryptionKey())
        .map(value =>
          zio.aws.workspaces.model.primitives.VolumeEncryptionKey(value)
        )
    override val userVolumeEncryptionEnabled: Optional[BooleanObject] =
      zio.aws.core.internal
        .optionalFromNullable(impl.userVolumeEncryptionEnabled())
        .map(value => value: BooleanObject)
    override val rootVolumeEncryptionEnabled: Optional[BooleanObject] =
      zio.aws.core.internal
        .optionalFromNullable(impl.rootVolumeEncryptionEnabled())
        .map(value => value: BooleanObject)
    override val workspaceProperties
        : Optional[zio.aws.workspaces.model.WorkspaceProperties.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.workspaceProperties())
        .map(value => zio.aws.workspaces.model.WorkspaceProperties.wrap(value))
    override val modificationStates
        : Optional[List[zio.aws.workspaces.model.ModificationState.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.modificationStates())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.workspaces.model.ModificationState.wrap(item)
          }.toList
        )
    override val relatedWorkspaces: Optional[
      List[zio.aws.workspaces.model.RelatedWorkspaceProperties.ReadOnly]
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.relatedWorkspaces())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.workspaces.model.RelatedWorkspaceProperties.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.workspaces.model.Workspace
  ): zio.aws.workspaces.model.Workspace.ReadOnly = new Wrapper(impl)
}
